import unittest
import math
import pandas as pd
from pandas.testing import assert_frame_equal
from list_overlap import Overlaps

df_fs       = Overlaps(df)
df_string   = df_fs.get_the_overlaps(df)
df_neu      = getoverlaps(df_n)
df_neumeric = df_neu.get_the_overlaps(df_n)

class TestReturnCalculations(unittest.TestCase):
    def overlap_neumeric(self):
        """
         Creating two DataFrame: df_n: neumeric dataframe
                                 df: string dataframe
         Setup: testing for both cases a dataframe of neumeric values and secound function test for a dataframe of string values
        """
        data_n = {'A':[1,2,3],'B': [1,2,3,4],'C':[5,2],'D': [2,8,9],'E': [2,11,5,9]}
        df_n = pd.DataFrame.from_dict(data_n, orient='index').T
        data = {'A':['D','KIT','SAP'],'B': ['F','G','LUFT','SAP'],'C':['I','SAP'],'D': ['SAP','LUF','KIT'],'E': ['SAP','LUF','KIT','HASS']}
        df   = pd.DataFrame.from_dict(data, orient='index').T
        # Expectation
        expected_n = df_neumeric
        # Call function
        actual_n   = df_neu.get_the_overlaps(df_n)
        # Test
        assert_frame_equal(actual, expected)

    def overlap_string(self):
        """"
        Test the overlap for the dataframe with strings
    
        """
            # Expectation
        expected_s=df_string

            # Call function
        actual_s = df_neu.get_the_overlaps(df)

            # Test
        assert_frame_equal(actual_s, expected_s)

if __name__ == "__main__":
    unittest.main()


#!/usr/bin/env python3
import pandas as pd
#import os
import itertools as it
import itertools  

class Overlaps:
    """
    Instantiate a the overlap search operation.
    
    :param df: The dataframe
    :type df: The columns can be type integer or string
    """
    
    def __init__(self, df):
        self.df = df
    
    def get_the_overlaps(self,df):
    
        """
        Get the overlaps between the columns of the dataframe df.
    
        :param df: The dataframe
        :type df: The columns can be type integer or string

        """
    ## lists from the dataframe; filter for None or Na values 
        lists = [[y for y in x if pd.notna(y)] for x in df.values.T.tolist()]
    # orient as list
        master_dict = df.to_dict('list')
        combinations =[]
        for l in range(2, len(lists) + 1):
            combinations += itertools.combinations(lists, l)
        key_list    = []
        for i in range(2,len(master_dict) +1):
            for combo in it.combinations(master_dict.keys(), i):
                new_key = "".join(combo)
                if (len(combo)>1):
                    key_list.append(new_key)
        final_dict = dict()
        for key, elem in zip(key_list, combinations):
            final_dict[key] = list(elem)
        overlap_list  = []
        dfs = []
        for k,v in final_dict.items():
            overlap = list(set.intersection(*[set(x) for x in v]))
            overlap_list.append(overlap)
         #print(overlap, sep=", ")
            dct  ={ 'overlaps':overlap,'number of overlaps':len(overlap),
              'overlap columns':k}
            dfs.append(dct)
        df_final          = pd.DataFrame.from_dict(dfs)
        return df_final


import pathlib
from setuptools import setup, find_packages

HERE = pathlib.Path(__file__).parent

VERSION = '0.1.0'
PACKAGE_NAME = 'vennoverlap'
AUTHOR = 'Alva Rani James'
AUTHOR_EMAIL = 'alvarani@gmail.com'
URL = 'https://github.com/ranijames/Data_overlap'

LICENSE = 'MIT License'
DESCRIPTION = 'vennoverlap is a package which would help to generate lists of overlaps between columns of given dataframe. eg. If you plot a venn diagram between 2 or more list, it will not provide you the values. But this library will gives you the value'
LONG_DESCRIPTION = (HERE / "README.md").read_text()
LONG_DESC_TYPE = "text/markdown"

INSTALL_REQUIRES = [
         'pandas',
        'itertools'
]


PYTHON_REQUIRES = ">=3.8"
setup(name=PACKAGE_NAME,
      version=VERSION,
      description=DESCRIPTION,
      long_description=LONG_DESCRIPTION,
      long_description_content_type=LONG_DESC_TYPE,
      author=AUTHOR,
      license=LICENSE,
      author_email=AUTHOR_EMAIL,
      url=URL,
      install_requires=INSTALL_REQUIRES,
      packages=find_packages()
      )